@@ -1,5 +1,5 @@
 """
-Ansi formatting for consoles,
+Colored consoles(Ansi formatting),
 Written in c++ by 'Arman Ahmadi' with (armanagha6@gmail.com) email!
 
 Ansi mode will enable automatically
